@@ -18,6 +18,8 @@ import * as iotidentity from './iotidentity/iotidentityclient';
 import * as greengrass from './greengrass/discoveryclient';
 import * as iotjobs from './iotjobs/iotjobsclient';
 import * as iotshadow from './iotshadow/iotshadowclient';
+import * as eventstream_rpc from './eventstream_rpc';
+import * as greengrasscoreipc from './greengrasscoreipc';
 
 import {
     auth,
@@ -31,7 +33,9 @@ import {
 
 export {
     auth,
+    eventstream_rpc,
     greengrass,
+    greengrasscoreipc,
     http,
     io,
     iot,
